@@ -151,22 +151,22 @@ class APIClient(object):
 
     def get_cases(self, studyid):
         """
-        Get slide data (no slides) for all slides in the study.
+        Get all case names and IDs
         Parameters
         ----------
         studyid : int
         Returns
         -------
         dict
-            Dictionary containing the images in the study.
-        For example to download all slides in a study with id 1 into the current directory you need to do 
+            Dictionary containing the cases in the study.
+        For example:
             client = APIClient(url, token)
-            for f in client.get_images(1):
-                client.download_slide(1, f["id"], ".")
+            for c in client.get_cases(1):
+                print(str(c["id"])+" - " + c["name"])
 
         
         """    
-        response = self.perform_request("Images", {"studyid": studyid})
+        response = self.perform_request("Cases", {"studyid": studyid})
         rjson = response.json()
         return rjson
 
@@ -229,6 +229,25 @@ class APIClient(object):
             raise SlideScoreErrorException(f"Configuration for study id {study_id} not returned succesfully")
 
         return rjson["config"]        
+
+    def get_config_files(self, study_id):
+        """
+        Get the configuration files of a particular study. Returns a dictionary with file contents for each file.
+        Parameters
+        ----------
+        study_id : int
+            ID of SlideScore study.
+        Returns
+        -------
+        dict
+        """
+        response = self.perform_request("GetConfigFiles", {"studyid": study_id})
+        rjson = response.json()
+
+        if not rjson["success"]:
+            raise SlideScoreErrorException(f"Configuration for study id {study_id} not returned succesfully")
+
+        return rjson        
         
     def upload_results(self, studyid, results):
         """
@@ -355,7 +374,7 @@ class APIClient(object):
     def add_slide(self, study_id, destination_filename):
         
         response = self.perform_request("AddSlide", {"studyId": study_id, "path": destination_filename}, method="POST")
-        if response.text != '"OK"':
+        if response.text != '"OK"' and response.text != '{}':
             raise SlideScoreErrorException("Failed adding slide: " + response.text);
 
     def reimport(self, study_name):
@@ -374,9 +393,29 @@ class APIClient(object):
             raise SlideScoreErrorException("Failed getting slide path: " + response.text);
         return rjson['path'] 
         
+    def get_slide_description(self, image_id):
+        response = self.perform_request("GetSlideDescription", {"imageId": image_id}, method="GET")
+        rjson = response.json()
+        if not rjson["success"]:
+            raise SlideScoreErrorException("Failed getting slide description: " + response.text);
+        return rjson['description'] 
+        
+    def get_case_description(self, case_id):
+        response = self.perform_request("GetCaseDescription", {"caseId": case_id}, method="GET")
+        rjson = response.json()
+        if not rjson["success"]:
+            raise SlideScoreErrorException("Failed getting case description: " + response.text);
+        return rjson['description'] 
+        
 
     def update_slide_path(self, image_id, new_path):
         response = self.perform_request("UpdateSlidePath", {"imageId": image_id, "newPath": new_path}, method="POST")
         rjson = response.json()
         if not rjson["success"]:
             raise SlideScoreErrorException("Failed updating slide path: " + response.text);
+
+    def update_slide_description(self, study_id, image_id, new_description):
+        response = self.perform_request("SetSlideDescription", {"imageId": image_id, "studyId": study_id, "description": new_description}, method="POST")
+        rjson = response.json()
+        if response.text != '{}':
+            raise SlideScoreErrorException("Failed updating slide description: " + response.text);
